==> open-xchange-subscribe_7.10.3.orig.tar.bz2: open-xchange-subscribe-7.10.3/com.openexchange.subscribe.xing/src/com/openexchange/subscribe/xing/osgi/OAuthServiceMetaDataRegisterer.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.subscribe.xing.osgi;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import com.openexchange.oauth.KnownApi;
import com.openexchange.oauth.OAuthServiceMetaData;

/**
 * {@link OAuthServiceMetaDataRegisterer}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class OAuthServiceMetaDataRegisterer implements ServiceTrackerCustomizer<OAuthServiceMetaData, OAuthServiceMetaData> {

    private final BundleContext context;
    private final XingSubscribeActivator activator;
    private final String xingIdentifier;

    /**
     * Initializes a new {@link OAuthServiceMetaDataRegisterer}.
     *
     * @param context The bundle context
     * @param activator The activator to track/start services
     */
    public OAuthServiceMetaDataRegisterer(final BundleContext context, final XingSubscribeActivator activator) {
        super();
        xingIdentifier = KnownApi.XING.getServiceId();
        this.context = context;
        this.activator = activator;
    }

    @Override
    public OAuthServiceMetaData addingService(final ServiceReference<OAuthServiceMetaData> reference) {
        final OAuthServiceMetaData oAuthServiceMetaData = context.getService(reference);
        if (xingIdentifier.equals(oAuthServiceMetaData.getId())) {
            activator.setOAuthServiceMetaData(oAuthServiceMetaData);
            activator.registerSubscribeService();
        }
        return oAuthServiceMetaData;
    }

    @Override
    public void modifiedService(final ServiceReference<OAuthServiceMetaData> arg0, final OAuthServiceMetaData arg1) {
        // nothing to do here
    }

    @Override
    public void removedService(final ServiceReference<OAuthServiceMetaData> reference, final OAuthServiceMetaData arg1) {
        final OAuthServiceMetaData oAuthServiceMetaData = arg1;
        if (xingIdentifier.equals(oAuthServiceMetaData.getId())) {
            activator.setOAuthServiceMetaData(null);
            activator.unregisterSubscribeService();
        }
        context.ungetService(reference);
    }
}

==> open-xchange-subscribe_7.10.5.orig.tar.bz2: open-xchange-subscribe-7.10.5/com.openexchange.subscribe.xing/src/com/openexchange/subscribe/xing/osgi/OAuthServiceMetaDataRegisterer.java <==
/*
 * @copyright Copyright (c) OX Software GmbH, Germany <info@open-xchange.com>
 * @license AGPL-3.0
 *
 * This code is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with OX App Suite.  If not, see <https://www.gnu.org/licenses/agpl-3.0.txt>.
 *
 * Any use of the work other than as authorized under this license or copyright law is prohibited.
 *
 */

package com.openexchange.subscribe.xing.osgi;

import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import com.openexchange.exception.OXException;
import com.openexchange.oauth.KnownApi;
import com.openexchange.oauth.OAuthServiceMetaData;

/**
 * {@link OAuthServiceMetaDataRegisterer}
 *
 * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
 */
public class OAuthServiceMetaDataRegisterer implements ServiceTrackerCustomizer<OAuthServiceMetaData, OAuthServiceMetaData> {

    private static final Logger LOG = LoggerFactory.getLogger(OAuthServiceMetaDataRegisterer.class);

    private final BundleContext context;
    private final XingSubscribeActivator activator;
    private final String xingIdentifier;

    /**
     * Initializes a new {@link OAuthServiceMetaDataRegisterer}.
     *
     * @param context The bundle context
     * @param activator The activator to track/start services
     */
    public OAuthServiceMetaDataRegisterer(final BundleContext context, final XingSubscribeActivator activator) {
        super();
        xingIdentifier = KnownApi.XING.getServiceId();
        this.context = context;
        this.activator = activator;
    }

    @Override
    public OAuthServiceMetaData addingService(final ServiceReference<OAuthServiceMetaData> reference) {
        final OAuthServiceMetaData oAuthServiceMetaData = context.getService(reference);
        if (xingIdentifier.equals(oAuthServiceMetaData.getId())) {
            activator.setOAuthServiceMetaData(oAuthServiceMetaData);
            try {
                activator.registerSubscribeService();
            } catch (OXException e) {
                LOG.error("Unable to create Xing Contact subscription services: " + e.getMessage(), e);
                return null;
            }
        }
        return oAuthServiceMetaData;
    }

    @Override
    public void modifiedService(final ServiceReference<OAuthServiceMetaData> arg0, final OAuthServiceMetaData arg1) {
        // nothing to do here
    }

    @Override
    public void removedService(final ServiceReference<OAuthServiceMetaData> reference, final OAuthServiceMetaData arg1) {
        final OAuthServiceMetaData oAuthServiceMetaData = arg1;
        if (xingIdentifier.equals(oAuthServiceMetaData.getId())) {
            activator.setOAuthServiceMetaData(null);
            activator.unregisterSubscribeService();
        }
        context.ungetService(reference);
    }
}
